==> mail-1.0.tar.gz: mail-1.0/source/javax/mail/search/FromStringTerm.java <==
/*
 * FromStringTerm.java
 * Copyright (C) 2002 The Free Software Foundation
 * 
 * This file is part of GNU JavaMail, a library.
 * 
 * GNU JavaMail is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * GNU JavaMail is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * As a special exception, if you link this library with other files to
 * produce an executable, this library does not by itself cause the
 * resulting executable to be covered by the GNU General Public License.
 * This exception does not however invalidate any other reasons why the
 * executable file might be covered by the GNU General Public License.
 */

package javax.mail.search;

import javax.mail.Address;
import javax.mail.Message;

/**
 * This class implements string comparisons for the From Address header.
 * <p>
 * Note that this class differs from the FromTerm class in that this class 
 * does comparisons on address strings rather than Address objects. The 
 * string comparisons are case-insensitive.
 *
 * @author <a href="mailto:dog@gnu.org">Chris Burdess</a>
 * @version 1.3
 */
public final class FromStringTerm
  extends AddressStringTerm
{

  /**
   * Constructor.
   * @param address the address pattern to be compared.
   */
  public FromStringTerm(String pattern)
  {
    super(pattern);
  }

  /**
   * Check whether the address string specified in the constructor is a
   * substring of the From address of this Message.
   * @param msg The comparison is applied to this Message's From address.
   * @return true if the match succeeds, otherwise false.
   */
  public boolean match(Message msg)
  {
    try
    {
      Address[] addresses = msg.getFrom();
      if (addresses!=null)
      {
        for (int i = 0; i<addresses.length; i++)
        {
          if (super.match(addresses[i]))
            return true;
        }
      }
    }
    catch (Exception e)
    {
    }
    return false;
  }

  /**
   * Equality comparison.
   */
  public boolean equals(Object other)
  {
    return (other instanceof FromStringTerm && super.equals(other));
  }

}

==> mail-1.1.1.tar.gz: mail-1.1.1/source/javax/mail/search/FromStringTerm.java <==
/*
 * FromStringTerm.java
 * Copyright (C) 2002 The Free Software Foundation
 * 
 * This file is part of GNU JavaMail, a library.
 * 
 * GNU JavaMail is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * GNU JavaMail is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * As a special exception, if you link this library with other files to
 * produce an executable, this library does not by itself cause the
 * resulting executable to be covered by the GNU General Public License.
 * This exception does not however invalidate any other reasons why the
 * executable file might be covered by the GNU General Public License.
 */

package javax.mail.search;

import javax.mail.Address;
import javax.mail.Message;

/**
 * A string comparison of the <i>From</i> address header.
 *
 * @author <a href="mailto:dog@gnu.org">Chris Burdess</a>
 * @version 1.3
 */
public final class FromStringTerm
  extends AddressStringTerm
{

  /**
   * Constructor.
   * @param address the address pattern for comparison
   */
  public FromStringTerm(String pattern)
  {
    super(pattern);
  }

  /**
   * Indicates whether the address pattern specified in the constructor is a
   * substring of the string representation of the From address in the given
   * message.
   * @param msg the message
   */
  public boolean match(Message msg)
  {
    try
      {
        Address[] addresses = msg.getFrom();
        if (addresses != null)
          {
            for (int i = 0; i < addresses.length; i++)
              {
                if (super.match(addresses[i]))
                  {
                    return true;
                  }
              }
          }
      }
    catch (Exception e)
      {
      }
    return false;
  }

  public boolean equals(Object other)
  {
    return (other instanceof FromStringTerm && super.equals(other));
  }

}
